@@ -250,14 +250,6 @@ struct rsm1
          0 - initial solution
          1 - primal feasible solution
          2 - optimal solution */
-      int form;
-      /* this parameter specifies what form of the basis matrix should
-         be used by the solver:
-         0 - PFI
-         1 - RFI + Bartels & Golub updating technique
-         2 - RFI + Forrest & Tomlin updating technique
-         3 - AFI
-         4 - UFI */
       int scale;
       /* if this flag is set, the solver performs automatic scaling the
          problem; otherwise the scaling is not used */
@@ -333,14 +325,6 @@ struct bbm1
          relaxation:
          0 - rsm1_driver()
          1 - glp_simplex2() */
-      int form;
-      /* this parameter specifies what form of the basis matrix should
-         be used by the solver:
-         0 - PFI
-         1 - RFI + Bartels & Golub updating technique
-         2 - RFI + Forrest & Tomlin updating technique
-         3 - AFI
-         4 - UFI */
       int scale;
       /* if this flag is set, the solver performs automatic scaling the
          problem; otherwise the scaling is not used */
@@ -381,14 +365,6 @@ extern int glp_call_bbm1(LPI *lpi, struct bbm1 *parm);
 
 struct spx1
 {     /* comprehensive simplex driver parameter block */
-      int form;
-      /* this parameter specifies what form of the basis matrix should
-         be used by the solver:
-         0 - PFI
-         1 - RFI + Bartels & Golub updating technique
-         2 - RFI + Forrest & Tomlin updating technique
-         3 - AFI
-         4 - UFI */
       int scale;
       /* this parameter controls the scaling option:
          0 - do not scale the problem
@@ -482,14 +458,6 @@ extern int glp_simplex1(LPI *lp, struct spx1 *_parm);
 
 struct piv1
 {     /* pivoting simplex driver parameter block */
-      int form;
-      /* this parameter specifies what form of the basis matrix should
-         be used by the routine:
-         0 - PFI
-         1 - RFI + Bartels & Golub updating technique
-         2 - RFI + Forrest & Tomlin updating technique
-         3 - AFI
-         4 - UFI */
       int scale;
       /* this parameter controls the scaling option:
          0 - do not scale the constraint matrix
