@@ -1,26 +1,26 @@
 /* glplang.h */
 
 /*----------------------------------------------------------------------
--- This file is a part of the GLPK package.
+-- Copyright (C) 2000, 2001, 2002 Andrew Makhorin <mao@mai2.rcnet.ru>,
+--               Department for Applied Informatics, Moscow Aviation
+--               Institute, Moscow, Russia. All rights reserved.
 --
--- Copyright (C) 2000, 2001 Andrew Makhorin <mao@mai2.rcnet.ru>,
---                          Department for Applied Informatics,
---                          Moscow Aviation Institute, Moscow, Russia.
---                          All rights reserved.
+-- This file is a part of GLPK (GNU Linear Programming Kit).
 --
--- This code is free software; you can redistribute it and/or modify
--- it under the terms of the GNU General Public License as published by
--- the Free Software Foundation; either version 2 of the License, or
--- (at your option) any later version.
+-- GLPK is free software; you can redistribute it and/or modify it
+-- under the terms of the GNU General Public License as published by
+-- the Free Software Foundation; either version 2, or (at your option)
+-- any later version.
 --
--- This software is distributed "as is" in the hope that it will be
--- useful, but WITHOUT ANY WARRANTY; without even the implied warranty
--- of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
--- General Public License for more details.
+-- GLPK is distributed in the hope that it will be useful, but WITHOUT
+-- ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
+-- or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public
+-- License for more details.
 --
 -- You should have received a copy of the GNU General Public License
--- along with this program; if not, write to the Free Software
--- Foundation, 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA.
+-- along with GLPK; see the file COPYING. If not, write to the Free
+-- Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
+-- 02111-1307, USA.
 ----------------------------------------------------------------------*/
 
 #ifndef _GLPLANG_H
@@ -28,7 +28,7 @@
 
 #include <setjmp.h>
 #include "glpavl.h"
-#include "glpset.h"
+#include "glplib.h"
 #include "glptext.h"
 
 #define addition              _glp_l_addition
