@@ -26,17 +26,12 @@
 #ifndef _GLPRSM_H
 #define _GLPRSM_H
 
-#include "glppfi.h"
+#include "glpinv.h"
 #include "glpk.h"
 #include "glplp.h"
-#include "glprfi.h"
 
-#define afi_btran             _glp_afi_btran
-#define afi_ftran             _glp_afi_ftran
 #define btran                 _glp_btran
-#define build_afi             _glp_build_afi
 #define build_basis           _glp_build_basis
-#define build_ufi             _glp_build_ufi
 #define change_b              _glp_change_b
 #define check_bbar            _glp_check_bbar
 #define check_cbar            _glp_check_cbar
@@ -45,12 +40,8 @@
 #define check_rr              _glp_check_rr
 #define check_rsm             _glp_check_rsm
 #define crash_aa              _glp_crash_aa
-#define create_afi            _glp_create_afi
 #define create_rsm            _glp_create_rsm
-#define create_ufi            _glp_create_ufi
 #define delete_rsm            _glp_delete_rsm
-#define delete_afi            _glp_delete_afi
-#define delete_ufi            _glp_delete_ufi
 #define dual_col              _glp_dual_col
 #define dual_row              _glp_dual_row
 #define eval_bbar             _glp_eval_bbar
@@ -75,13 +66,9 @@
 #define rsm_primal            _glp_rsm_primal
 #define rsm1_driver           _glp_rsm1_driver
 #define scale_rsm             _glp_scale_rsm
-#define ufi_btran             _glp_ufi_btran
-#define ufi_ftran             _glp_ufi_ftran
 #define update_b              _glp_update_b
 #define update_dvec           _glp_update_dvec
 #define update_gvec           _glp_update_gvec
-#define update_afi            _glp_update_afi
-#define update_ufi            _glp_update_ufi
 
 typedef struct RSM RSM;
 
@@ -131,67 +118,13 @@ struct RSM
          'U' - non-basis variable on its upper bound
          'F' - non-basis free variable
          'S' - non-basis fixed variable */
-      PFI *pfi;
-      /* if PFI (Product Form of the Inverse) is used to represent the
-         current basis matrix B, pfi points to PFI; otherwise the pfi
-         field is NULL */
-      RFI *rfi;
-      /* if RFI (Reid's Form of the Inverse) is used to represent the
-         current basis matrix B, rfi points to RFI; otherwise the rfi
-         field is NULL */
-      void *afi;
-      /* if AFI (Advanced Form of the Inverse) is used to represent the
-         current basis matrix B, afi points to AFI; otherwise the afi
-         field is NULL */
-      void *ufi;
-      /* if UFI (User's Form of the Inverse) is used to represent the
-         current basis matrix B, ufi points to the user data structure;
-         otherwise the ufi field is NULL */
+      INV *inv;
+      /* an invertable (factorized) form of the basis matrix */
       int iter;
       /* iteration count (increased each time when the current basis is
          replaced by the adjacent one) */
 };
 
-/*** advanced form of the inverse ***/
-
-extern void *create_afi(int m);
-/* create AFI */
-
-extern int build_afi(void *afi, MAT *A, int indb[]);
-/* build AFI for given basis matrix */
-
-extern double *afi_ftran(void *afi, double z[], int save);
-/* perform forward transformation (FTRAN) using AFI */
-
-extern double *afi_btran(void *afi, double z[]);
-/* perform backward transformation (BTRAN) using AFI */
-
-extern int update_afi(void *afi, int p);
-/* update AFI for adjacent basis matrix */
-
-extern void delete_afi(void *afi);
-/* delete AFI */
-
-/*** user's form of the inverse ***/
-
-extern void *create_ufi(int m);
-/* create UFI */
-
-extern int build_ufi(void *ufi, MAT *A, int indb[]);
-/* build UFI for given basis matrix */
-
-extern double *ufi_ftran(void *ufi, double z[], int save);
-/* perform forward transformation (FTRAN) using UFI */
-
-extern double *ufi_btran(void *ufi, double z[]);
-/* perform backward transformation (BTRAN) using UFI */
-
-extern int update_ufi(void *ufi, int p);
-/* update UFI for adjacent basis matrix */
-
-extern void delete_ufi(void *ufi);
-/* delete UFI */
-
 /*** operations on basis matrix ***/
 
 extern int invert_b(RSM *rsm);
@@ -327,14 +260,6 @@ struct rsm1_cp
          0 - initial solution
          1 - primal feasible solution
          2 - optimal solution */
-      int form;
-      /* this parameter specifies what form of the basis matrix should
-         be used by the solver:
-         0 - PFI
-         1 - RFI + Bartels & Golub updating technique
-         2 - RFI + Forrest & Tomlin updating technique
-         3 - AFI
-         4 - UFI */
       int scale;
       /* if this flag is set, the solver performs automatic scaling the
          problem; otherwise the scaling is not used */
@@ -373,7 +298,7 @@ extern int rsm1_driver(LP *lp, LPSOL *sol, struct rsm1_cp *cp);
 
 /*** auxiliary routines ***/
 
-extern RSM *create_rsm(LPI *lp, int form);
+extern RSM *create_rsm(LPI *lp);
 /* create revised simplex method common block */
 
 extern void delete_rsm(RSM *rsm);
