@@ -26,7 +26,7 @@
 #ifndef _GLPSPX_H
 #define _GLPSPX_H
 
-#include "glpfhv.h"
+#include "glpinv.h"
 
 #define spx_get_aj            _glp_spx_get_aj
 #define spx_get_ak            _glp_spx_get_ak
@@ -80,9 +80,9 @@ struct SPXMAT
 
 struct SPXBAS
 {     /* representation of the basis matrix */
-      /* currently this representation is based on FHV-factorization */
-      FHV *fhv;
-      /* pointer to FHV-factorization of the basis matrix */
+      /* currently this representation is based on LU-factorization */
+      INV *inv;
+      /* pointer to an invertable form of the basis matrix */
 };
 
 extern int spx_get_aj(SPXMAT *A, int j, int rn[], double aj[]);
