@@ -38,7 +38,7 @@
 -- based on the revised simplex method is used.
 ----------------------------------------------------------------------*/
 
-static char *version = "GLPSOL -- GLPK LP/MIP Solver, Version 3.0.5";
+static char *version = "GLPSOL -- GLPK LP/MIP Solver, Version 3.0.6";
 
 static char *in_fname = NULL;
 /* name of the input text file */
@@ -82,15 +82,6 @@ static int scale = 1;
 /* if this flag is set, the solver performs automatic scaling the
    problem before solving; otherwise scaling is not used */
 
-static int form = 3;
-/* this parameter specifies what form of the basis matrix should be used
-   by the solver:
-   0 - PFI
-   1 - RFI + Bartels & Golub updating technique
-   2 - RFI + Forrest & Tomlin updating technique
-   3 - AFI
-   4 - UFI */
-
 static int use_dual = 0;
 /* if this flag is set, the solver uses the dual simplex method for
    searching for feasible solution; otherwise the solver uses the primal
@@ -165,16 +156,6 @@ static void display_help(char *my_name)
       print("   -v, --version     display program version and exit");
       print("");
       print("Options specific to simplex method (--old-sim assumed):");
-      print("   --textbook        use options --noscale, --pfi, --prima"
-         "l, --nosteep,");
-      print("                     --norelax, --first, and --lifo by def"
-         "ault");
-      print("   --pfi             use PFI");
-      print("   --rfi-bg          use RFI + Bartels and Golub updating "
-         "technique");
-      print("   --rfi-ft          use RFI + Forrest and Tomlin updating"
-         " technique");
-      print("   --afi             use AFI (default)");
       print("   --primal          find feasible solution using primal s"
          "implex");
       print("                     (default)");
@@ -286,25 +267,6 @@ static void process_cmdline(int argc, char *argv[])
             display_help(argv[0]);
          else if (p("-v") || p("--version"))
             display_version();
-         else if (p("--textbook"))
-         {  scale = 0;
-            form = 0;
-            use_dual = 0;
-            steep = 0;
-            relax = 0;
-            branch = BB_FIRST;
-            btrack = BB_LIFO;
-         }
-         else if (p("--pfi"))
-            form = 0;
-         else if (p("--rfi-bg"))
-            form = 1;
-         else if (p("--rfi-ft"))
-            form = 2;
-         else if (p("--afi"))
-            form = 3;
-         else if (p("--ufi"))
-            form = 4;
          else if (p("--primal"))
             use_dual = 0;
          else if (p("--dual"))
@@ -396,7 +358,6 @@ int main(int argc, char *argv[])
                {  struct rsm1 parm;
                   glp_init_rsm1(&parm);
                   parm.what = option;
-                  parm.form = form;
                   parm.scale = scale;
                   parm.dual = use_dual;
                   parm.steep = steep;
@@ -417,7 +378,6 @@ int main(int argc, char *argv[])
                parm.branch = branch;
                parm.btrack = btrack;
                parm.meth = (method == 'O' ? 0 : 1);
-               parm.form = form;
                parm.scale = scale;
                parm.dual = use_dual;
                parm.steep = steep;
@@ -461,6 +421,10 @@ int main(int argc, char *argv[])
       }
 skip: /* delete the problem object */
       glp_delete_prob(lp);
+#if 0
+      print("%d %d",
+         get_env_ptr()->mem_total, get_env_ptr()->mem_count);
+#endif
       /* exit to the control program */
       return 0;
 }
