@@ -26,9 +26,11 @@
 #include <float.h>
 #include <stddef.h>
 #include <glpk.h>
-#include <glpset.h>
+#include <glplib.h>
 #include "lp.h"
 
+#define error print
+
 /*----------------------------------------------------------------------
 -- This is a non-trivial example of using GLPK as a base LP solver for
 -- Concorde, a program for solving Traveling Salesman Problem (TSP).
