@@ -34,7 +34,7 @@ s19:  glp_new_aij(lp, 3, 3, 6.0);
 
 s20:  glp_set_obj_sense(lp, '+');
 
-s21:  glp_call_rsm1(lp, NULL);
+s21:  glp_simplex2(lp, NULL);
 
 s22:  Z = glp_get_obj_val(lp);
 s23:  glp_get_col_soln(lp, 1, NULL, &x1, NULL);
