@@ -44,8 +44,7 @@
 -- driver routines glp_pivot_in and glp_pivot_out by default values. */
 
 void glp_init_piv1(struct piv1 *parm)
-{     parm->form = 3;
-      parm->scale = 0;
+{     parm->scale = 0;
       parm->tol = 0.01;
       return;
 }
@@ -60,11 +59,7 @@ void glp_init_piv1(struct piv1 *parm)
 -- 1 - some control parameter has invalid value. */
 
 static int check_parm(char *who, struct piv1 *p)
-{     if (!(0 <= p->form && p->form <= 4))
-      {  error("%s: form = %d; invalid parameter", who, p->form);
-         return 1;
-      }
-      if (!(p->scale == 0 || p->scale == 1))
+{     if (!(p->scale == 0 || p->scale == 1))
       {  error("%s: scale = %d; invalid parameter", who, p->scale);
          return 1;
       }
@@ -230,7 +225,7 @@ int glp_pivot_in(LPI *lp, int flag[], struct piv1 *parm)
       }
       if (i > m) return -1;
       /* create RSM */
-      rsm = create_rsm(lp, parm->form);
+      rsm = create_rsm(lp);
       /* scale the constraint matrix (if required) */
       if (parm->scale) scale_matrix(rsm, lp);
       /* allocate auxiliary array */
@@ -378,7 +373,7 @@ int glp_pivot_out(LPI *lp, int flag[], struct piv1 parm[])
       }
       if (j > n) return -1;
       /* create RSM */
-      rsm = create_rsm(lp, parm->form);
+      rsm = create_rsm(lp);
       /* scale the constraint matrix (if required) */
       if (parm->scale) scale_matrix(rsm, lp);
       /* allocate auxiliary arrays */
