@@ -197,47 +197,7 @@ static void initialize(LP *mip, LPSOL *sol)
       bb->rsm->indb = ucalloc(1+m, sizeof(int));
       bb->rsm->indn = ucalloc(1+n, sizeof(int));
       bb->rsm->tagn = ucalloc(1+n, sizeof(int));
-      switch (cp->form)
-      {  case 0:
-            /* use PFI */
-            bb->rsm->pfi = create_pfi(m);
-            bb->rsm->rfi = NULL;
-            bb->rsm->afi = NULL;
-            bb->rsm->ufi = NULL;
-            break;
-         case 1:
-            /* use RFI + Bartels & Golub updating technique */
-            bb->rsm->pfi = NULL;
-            bb->rsm->rfi = create_rfi(m);
-            bb->rsm->rfi->tech = RFI_BG;
-            bb->rsm->afi = NULL;
-            bb->rsm->ufi = NULL;
-            break;
-         case 2:
-            /* use RFI + Forrest & Tomlin updating technique */
-            bb->rsm->pfi = NULL;
-            bb->rsm->rfi = create_rfi(m);
-            bb->rsm->rfi->tech = RFI_FT;
-            bb->rsm->afi = NULL;
-            bb->rsm->ufi = NULL;
-            break;
-         case 3:
-            /* use AFI */
-            bb->rsm->pfi = NULL;
-            bb->rsm->rfi = NULL;
-            bb->rsm->afi = create_afi(m);
-            bb->rsm->ufi = NULL;
-            break;
-         case 4:
-            /* use UFI */
-            bb->rsm->pfi = NULL;
-            bb->rsm->rfi = NULL;
-            bb->rsm->afi = NULL;
-            bb->rsm->ufi = create_ufi(m);
-            break;
-         default:
-            insist(cp->form != cp->form);
-      }
+      bb->rsm->inv = inv_create(m, 100);
       bb->rsm->iter = 0;
       /* so far as the RSM arrays type, lb, ub, posx, indb, indn, and
          tagn will be set later for each individual subproblem, these
@@ -1351,10 +1311,7 @@ static void terminate(void)
       ufree(bb->rsm->indb);
       ufree(bb->rsm->indn);
       ufree(bb->rsm->tagn);
-      if (bb->rsm->pfi != NULL) delete_pfi(bb->rsm->pfi);
-      if (bb->rsm->rfi != NULL) delete_rfi(bb->rsm->rfi);
-      if (bb->rsm->afi != NULL) delete_afi(bb->rsm->afi);
-      if (bb->rsm->ufi != NULL) delete_ufi(bb->rsm->ufi);
+      inv_delete(bb->rsm->inv);
       ufree(bb->rsm);
       ufree(bb->bbar);
       ufree(bb);
