@@ -26,6 +26,7 @@
 #include <float.h>
 #include <math.h>
 #include <stddef.h>
+#include "glpduff.h"
 #include "glprsm.h"
 
 /*----------------------------------------------------------------------
@@ -51,16 +52,7 @@
 -- locations. */
 
 void btran(RSM *rsm, double u[])
-{     if (rsm->pfi != NULL)
-         pfi_btran(rsm->pfi, u);
-      else if (rsm->rfi != NULL)
-         rfi_btran(rsm->rfi, u);
-      else if (rsm->afi != NULL)
-         afi_btran(rsm->afi, u);
-      else if (rsm->ufi != NULL)
-         ufi_btran(rsm->ufi, u);
-      else
-         insist(rsm != rsm);
+{     inv_btran(rsm->inv, u);
       return;
 }
 
@@ -883,7 +875,7 @@ int crash_aa(MAT *A, int tag[], PER *P, PER *Q)
 --
 -- The routine create_rsm() returns a pointer to the created block. */
 
-RSM *create_rsm(LPI *lp, int form)
+RSM *create_rsm(LPI *lp)
 {     RSM *rsm;
       int m = glp_get_num_rows(lp), n = glp_get_num_cols(lp), i, j, k;
       if (m == 0) fault("create_rsm: problem has no rows");
@@ -900,47 +892,7 @@ RSM *create_rsm(LPI *lp, int form)
       rsm->indb = ucalloc(1+m, sizeof(int));
       rsm->indn = ucalloc(1+n, sizeof(int));
       rsm->tagn = ucalloc(1+n, sizeof(int));
-      switch (form)
-      {  case 0:
-            /* use PFI */
-            rsm->pfi = create_pfi(m);
-            rsm->rfi = NULL;
-            rsm->afi = NULL;
-            rsm->ufi = NULL;
-            break;
-         case 1:
-            /* use RFI + Bartels & Golub updating technique */
-            rsm->pfi = NULL;
-            rsm->rfi = create_rfi(m);
-            rsm->rfi->tech = RFI_BG;
-            rsm->afi = NULL;
-            rsm->ufi = NULL;
-            break;
-         case 2:
-            /* use RFI + Forrest & Tomlin updating technique */
-            rsm->pfi = NULL;
-            rsm->rfi = create_rfi(m);
-            rsm->rfi->tech = RFI_FT;
-            rsm->afi = NULL;
-            rsm->ufi = NULL;
-            break;
-         case 3:
-            /* use AFI */
-            rsm->pfi = NULL;
-            rsm->rfi = NULL;
-            rsm->afi = create_afi(m);
-            rsm->ufi = NULL;
-            break;
-         case 4:
-            /* use UFI */
-            rsm->pfi = NULL;
-            rsm->rfi = NULL;
-            rsm->afi = NULL;
-            rsm->ufi = create_ufi(m);
-            break;
-         default:
-            fault("create_rsm: form = %d; invalid parameter", form);
-      }
+      rsm->inv = inv_create(m, 100);
       rsm->iter = 0;
       /* obtain types and bounds of rows */
       for (i = 1; i <= m; i++)
@@ -1027,10 +979,7 @@ void delete_rsm(RSM *rsm)
       ufree(rsm->indb);
       ufree(rsm->indn);
       ufree(rsm->tagn);
-      if (rsm->pfi != NULL) delete_pfi(rsm->pfi);
-      if (rsm->rfi != NULL) delete_rfi(rsm->rfi);
-      if (rsm->afi != NULL) delete_afi(rsm->afi);
-      if (rsm->ufi != NULL) delete_ufi(rsm->ufi);
+      inv_delete(rsm->inv);
       ufree(rsm);
       return;
 }
@@ -1647,16 +1596,7 @@ double exact_gvec(RSM *rsm, int j)
 -- the save flag set before subsequent call to the update_b routine. */
 
 void ftran(RSM *rsm, double u[], int save)
-{     if (rsm->pfi != NULL)
-         pfi_ftran(rsm->pfi, u, save);
-      else if (rsm->rfi != NULL)
-         rfi_ftran(rsm->rfi, u, save);
-      else if (rsm->afi != NULL)
-         afi_ftran(rsm->afi, u, save);
-      else if (rsm->ufi != NULL)
-         ufi_ftran(rsm->ufi, u, save);
-      else
-         insist(rsm != rsm);
+{     inv_ftran(rsm->inv, u, save);
       return;
 }
 
@@ -2063,18 +2003,24 @@ void init_gvec(RSM *rsm, double gvec[])
 -- futher information see descriptions of particular routines that
 -- perform this operation). */
 
+static int col(void *info, int j, int rn[], double bj[])
+{     /* build j-th column of the current basis matrix */
+      RSM *rsm = (RSM *)info;
+      ELEM *e;
+      int nz = 0;
+      for (e = rsm->A->col[rsm->indb[j]]; e != NULL; e = e->col)
+         if (e->val != 0) nz++, rn[nz] = e->i, bj[nz] = e->val;
+      return nz;
+}
+
 int invert_b(RSM *rsm)
-{     int ret;
-      if (rsm->pfi != NULL)
-         ret = build_pfi(rsm->pfi, rsm->A, rsm->indb);
-      else if (rsm->rfi != NULL)
-         ret = build_rfi(rsm->rfi, rsm->A, rsm->indb);
-      else if (rsm->afi != NULL)
-         ret = build_afi(rsm->afi, rsm->A, rsm->indb);
-      else if (rsm->ufi != NULL)
-         ret = build_ufi(rsm->ufi, rsm->A, rsm->indb);
-      else
-         insist(rsm != rsm);
+{     static double tol[1+3] = { 0.00, 0.10, 0.30, 0.70 };
+      int try, ret;
+      for (try = 1; try <= 3; try++)
+      {  rsm->inv->luf->piv_tol = tol[try];
+         ret = inv_decomp(rsm->inv, rsm, col);
+         if (ret == 0) break;
+      }
       return ret;
 }
 
@@ -2429,16 +2375,7 @@ void scale_rsm(RSM *rsm, double R[], double S[])
 
 int update_b(RSM *rsm, int p)
 {     int ret;
-      if (rsm->pfi != NULL)
-         ret = update_pfi(rsm->pfi, p);
-      else if (rsm->rfi != NULL)
-         ret = update_rfi(rsm->rfi, p);
-      else if (rsm->afi != NULL)
-         ret = update_afi(rsm->afi, p);
-      else if (rsm->ufi != NULL)
-         ret = update_ufi(rsm->ufi, p);
-      else
-         insist(rsm != rsm);
+      ret = inv_update(rsm->inv, p);
       return ret;
 }
 
